@@ -214,15 +214,15 @@ def ls(conf):
                 print((await c.receive())['result'].decode())
     trio.run(_ls, getattr(conf.worker, "cli_dial", conf.worker.dial))
 
-@main.command(help="Quit a worker")
+@main.command(help="Quit workers, by name / glob pattern")
 @global_options
-@click.option('-f', '--force', is_flag=True, help="Kill the worker even if it still have running jobs")
-@click.argument('worker_name')
-def quit(conf, force, worker_name):
+@click.option('-f', '--force', is_flag=True, help="Kill the worker(s) even if it still have running jobs")
+@click.argument('worker_name_pattern')
+def quit(conf, force, worker_name_pattern):
     async def _unreg(head, name):
         with _handle_connection_error(head):
             await notify(f"{head}", dict(cmd="UNR" if force else "TRM", name=name), seg=True)
-    trio.run(_unreg, getattr(conf.worker, "cli_dial", conf.worker.dial), worker_name)
+    trio.run(_unreg, getattr(conf.worker, "cli_dial", conf.worker.dial), worker_name_pattern)
 
 @contextmanager
 def _handle_connection_error(url):
