@@ -1,8 +1,11 @@
 import toml
 
 from os import environ as ENV
+import logging
+logger = logging.getLogger(__name__)
 
 DEFAULT_CONF = {
+    "contextmod": "",
     "head": {
         "name": "grain_head",
         "main_log_file": "/dev/null",
@@ -27,13 +30,13 @@ DEFAULT_CONF = {
 
 def load_conf(config=None):
     if config is False:
-        print("Config file is disabled, using default settings.")
+        logger.info("Config file is disabled, using default settings.")
         return odict(DEFAULT_CONF)
     config = config or ENV.get("GRAIN_CONFIG", "grain.toml")
     try:
         conf = toml.load(config)
     except FileNotFoundError:
-        print(f"Cannot find Grain config file {config!r}, using default settings.")
+        logger.warning(f"Cannot find Grain config file {config!r}, using default settings.")
         conf = {}
     setdefault(conf, DEFAULT_CONF)
     return odict(conf)
@@ -45,6 +48,12 @@ def setdefault(d, dflt): # NOTE: not dealing with list & tuple
             continue
         if isinstance(v, dict):
             setdefault(d[k],v)
+def override(d, sup):
+    for k,v in sup.items():
+        if k in d and isinstance(v, dict):
+            override(d[k],v)
+        else:
+            d[k] = v
 
 class odict(dict):
     def __init__(self, d):
