@@ -13,7 +13,7 @@ from collections.abc import Iterable
 
 
 async def each(*dos):
-    """A convinient helper function to await on a list of delayed
+    r"""A convinient helper function to await on a list of delayed
     objects.
 
     Args:
@@ -279,11 +279,13 @@ async def relay(inq):
 async def boot(subtasks, args, kwargs):
     global exer, _gn, rch
     from .head import GrainExecutor
+    from .remote_exer import RemoteExecutor
+    Exer = RemoteExecutor if 'gnaw' in kwargs else GrainExecutor
     from .delayed import relay # no global dependency
     from .util import open_ordered_nursery
     from collections.abc import Iterable
     async with trio.open_nursery() as _n, \
-               GrainExecutor(_n=_n, *args, **kwargs) as exer:
+               Exer(_n=_n, *args, **kwargs) as exer:
         rch = {}
         _n.start_soon(relay, exer.resultq)
         GVAR.instance = "N/A"
@@ -315,12 +317,15 @@ def run(subtasks, *args, **kwargs):
         exception instead of resubmitting the failed tasklet.
       persistent (bool): Default to true. If false, abort the scheduler whenever
         a worker quits prematurely.
-      config_file (str or None): Grain's config file name. If not set or None,
+      config_file (Union[str, False, None]): Grain's config file name. If not set or None,
         Grain will use the name provided by envar ``GRAIN_CONFIG``, and finally
         fallback to name ``grain.toml``. If set to False, Grain will use the
         default profile (see ``config.py``).
       stat_tag (Callable[~grain.resource.Resource, str]): Define how time statistics
         is categorized by resource. Jobs with resource that maps to the same
         str are grouped together.
+      gnaw (Optional[str]): If set, connect to the Gnaw executor with address
+        ``gnaw`` instead of using the built-in executor. If an empty str is
+        given, a Gnaw executor is started as a subprocess.
     """
     trio.run(boot, subtasks, args, kwargs)
